@@ -29,6 +29,11 @@ from ..bus import BusABC
 
 from ..broadcastmanager import CyclicSendTaskABC
 
+# struct module defines a binary packing format:
+# https://docs.python.org/3/library/struct.html#struct-format-strings
+# The 32bit can id is directly followed by the 8bit data link count
+# The data field is aligned on an 8 byte boundary, hence we add padding
+# which aligns the data field to an 8 byte boundary.
 can_frame_fmt = "=IB3x8s"
 can_frame_size = struct.calcsize(can_frame_fmt)
 
@@ -107,18 +112,6 @@ def dissect_can_frame(frame):
     return (can_id, can_dlc, data[:can_dlc])
 
 
-def create_bcm_socket(channel):
-    """create a broadcast manager socket and connect to the given interface"""
-    try:
-        s = socket.socket(socket.PF_CAN, socket.SOCK_DGRAM, socket.CAN_BCM)
-    except AttributeError:
-        raise SystemExit("To use BCM sockets you need Python3.4 or higher")
-    try:
-        s.connect((channel,))
-    except OSError as e:
-        log.error("Couldn't connect a broadcast manager socket")
-        raise e
-    return s
 
 
 class CyclicSendTask(CyclicSendTaskABC):
@@ -133,6 +126,19 @@ class CyclicSendTask(CyclicSendTaskABC):
         super(CyclicSendTask,self).__init__(channel, message, period)
         self.bcm_socket = create_bcm_socket(channel)
         self._tx_setup(message)
+        self.message = message
+    def create_bcm_socket(channel):
+        """create a broadcast manager socket and connect to the given interface"""
+        try:
+            s = socket.socket(socket.PF_CAN, socket.SOCK_DGRAM, socket.CAN_BCM)
+        except AttributeError:
+            raise SystemExit("To use BCM sockets you need Python3.4 or higher")
+        try:
+            s.connect((channel,))
+        except OSError as e:
+            log.error("Couldn't connect a broadcast manager socket")
+            raise e
+        return s
 
     def _tx_setup(self, message):
         # Create a low level packed frame to pass to the kernel
@@ -158,6 +164,11 @@ class CyclicSendTask(CyclicSendTaskABC):
         """
         assert message.arbitration_id == self.can_id, "You cannot modify the can identifier"
         self._tx_setup(message)
+        self.message
+
+
+    def start(self):
+        self._tx_setup(self.message)
 
 
 def createSocket(can_protocol=None):
@@ -293,6 +304,12 @@ class SocketscanNative_Bus(BusABC):
                                    socket.CAN_RAW_FILTER,
                                    struct.pack(can_filter_fmt, *filter_data),
                                    )
+        if channel is None:
+            # We know we are socketcan, a channel "should" have
+            # been given but we can assume "can0"
+            log.warn("Channel not given. Falling back to using 'can0'")
+            channel = 'can0'
+
         bindSocket(self.socket, channel)
         super(SocketscanNative_Bus, self).__init__()
 
@@ -324,24 +341,24 @@ class SocketscanNative_Bus(BusABC):
 
         return rx_msg
 
-    def send(self, message):
+    def send(self, msg):
         log.debug("We've been asked to write a message to the bus")
-        arbitration_id = message.arbitration_id
-        if message.id_type:
+        arbitration_id = msg.arbitration_id
+        if msg.id_type:
             log.debug("sending an extended id type message")
             arbitration_id |= 0x80000000
-        if message.is_remote_frame:
+        if msg.is_remote_frame:
             log.debug("requesting a remote frame")
             arbitration_id |= 0x40000000
-        if message.is_error_frame:
+        if msg.is_error_frame:
             log.warning("Trying to send an error frame - this won't work")
             arbitration_id |= 0x20000000
         l = log.getChild("tx")
-        l.debug("sending: %s", message)
+        l.debug("sending: %s", msg)
         try:
-            self.socket.send(build_can_frame(arbitration_id, message.data))
+            self.socket.send(build_can_frame(arbitration_id, msg.data))
         except OSError:
-            l.warning("Failed to send: %s", message)
+            l.warning("Failed to send: %s", msg)
 
 
 if __name__ == "__main__":
